==> gammaray_2.9.0.orig.tar.gz: gammaray-2.9.0/core/metapropertyadaptor.h <==
/*
  metapropertyadaptor.h

  This file is part of GammaRay, the Qt application inspection and
  manipulation tool.

  Copyright (C) 2015-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
  Author: Volker Krause <volker.krause@kdab.com>

  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
  accordance with GammaRay Commercial License Agreement provided with the Software.

  Contact info@kdab.com if any conditions of this licensing are not clear to you.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef GAMMARAY_METAPROPERTYADAPTOR_H
#define GAMMARAY_METAPROPERTYADAPTOR_H

#include "propertyadaptor.h"

namespace GammaRay {
class MetaObject;

/** Property access for GammaRay meta-type based property-access. */
class MetaPropertyAdaptor : public PropertyAdaptor
{
    Q_OBJECT
public:
    explicit MetaPropertyAdaptor(QObject *parent = nullptr);
    ~MetaPropertyAdaptor();

    int count() const override;
    PropertyData propertyData(int index) const override;
    void writeProperty(int index, const QVariant &value) override;

protected:
    void doSetObject(const ObjectInstance &oi) override;

private:
    MetaObject *m_metaObj;
    void *m_obj;
};
}

#endif // GAMMARAY_METAPROPERTYADAPTOR_H

==> gammaray_2.11.0.orig.tar.gz: gammaray-2.11.0/core/metapropertyadaptor.h <==
/*
  metapropertyadaptor.h

  This file is part of GammaRay, the Qt application inspection and
  manipulation tool.

  Copyright (C) 2015-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
  Author: Volker Krause <volker.krause@kdab.com>

  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
  accordance with GammaRay Commercial License Agreement provided with the Software.

  Contact info@kdab.com if any conditions of this licensing are not clear to you.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef GAMMARAY_METAPROPERTYADAPTOR_H
#define GAMMARAY_METAPROPERTYADAPTOR_H

#include "propertyadaptor.h"

namespace GammaRay {
class MetaObject;

/** Property access for GammaRay meta-type based property-access. */
class MetaPropertyAdaptor : public PropertyAdaptor
{
    Q_OBJECT
public:
    explicit MetaPropertyAdaptor(QObject *parent = nullptr);
    ~MetaPropertyAdaptor() override;

    int count() const override;
    PropertyData propertyData(int index) const override;
    void writeProperty(int index, const QVariant &value) override;

protected:
    void doSetObject(const ObjectInstance &oi) override;

private:
    MetaObject *m_metaObj;
    void *m_obj;
};
}

#endif // GAMMARAY_METAPROPERTYADAPTOR_H
